import ms from 'ms';
import { shortId } from '../helper/IdGenerate.js';
import MemoryDB from '../database/MemoryDB.js';

const defaultExpirationTime = process.env.EXPIRE_KEY_TIME ? ms(process.env.EXPIRE_KEY_TIME) : ms('3d');

class UrlShortener {
  static async shorten(req, url, expirationTime = defaultExpirationTime) {
    const id = shortId(url);
    const key = `url:${id}`;
    await MemoryDB.set(key, url, expirationTime);

    const shortUrl = `${req.get('host')}/${id}`;
    return shortUrl;
  }

  static async extend(key) {
    let url = await MemoryDB.get(`url:${key}`);
    return url;
  }
}

const { shorten, extend } = UrlShortener;

export {
  shorten,
  extend,
}

export default new UrlShortener();