import { shorten, extend } from '../controller/UrlShortener.js';

class UrlShortener {
  register(server) {
    server.post('/shorten', async (req, res) => {
      try {
        const { url } = req.body;

        if (!url) {
          return res.status(500).json({ error: 'Parâmetro {url} não fornecido' });
        }

        res.json({ shortUrl: await shorten(req, url) });
      } catch (error) {
        console.error(error);
        res.status(500).json({ error: 'Erro interno do servidor' });
      }
    });

    server.get('/:shortId', async (req, res) => {
      try {
        const { shortId } = req.params;
        const url = await extend(shortId);

        if (!url) {
          return res.status(500).json({ error: 'URL não encontrada ou expirada' });
        }

        res.redirect(url);
      } catch (error) {
        console.error(error);
        res.status(500).json({ error: 'Erro interno do servidor' });
      }
    });
  }
}

export default new UrlShortener();