import path from 'node:path';
import express from 'express';
import dotenv from 'dotenv';

import AppRoutes from './routes/App.js';
import AppMiddleware from './middleware/App.js';
import MemoryDB from './database/MemoryDB.js';

const backendPath = path.dirname(path.join(process.argv[1], '..'));
const envPath = path.join(backendPath, '.env');

dotenv.config({ path: envPath });

const app = express();
const port = process.env.SRV_PORT;

AppMiddleware.register(app);
AppRoutes.register(app);

(async () => {
  await MemoryDB.connect();
  app.listen(port, () => {
    console.log(`Listening in ${port}`);
  });
})();