import Base64 from '../helper/Base64.js';
import JWT from '../helper/JWT.js';
import Security from './Security.js';

class Auth {
  async isValidBasicAuth(authorization) {
    let authorized = false;
    let reason = 'VALID_CREDENTIALS';
    if (typeof authorization === 'string' && authorization.startsWith('Basic')) {
      const credential = Base64.decode(authorization.replace('Basic ', ''), false);
      const [username = '', password = ''] = credential?.split(':') || [];
      authorized = await Security.isAuthorizedUser(username, password);
      reason = 'INVALID_CREDENTIALS';
    } else {
      reason = 'NOT_FOUND_CREDENTIALS';
    }
    return { authorized, reason };
  }

  async isValidBearerAuth(authorization) {
    if (typeof authorization === 'string' && authorization.startsWith('Bearer')) {
      const credential = authorization.replace('Bearer ', '');
      const authorized = JWT.validate(credential);
      return { authorized, reason: authorized ? 'VALID_TOKEN' : 'INVALID_TOKEN' };
    }
    return { authorized: false, reason: 'NOT_FOUND_TOKEN' };
  }
}

export default new Auth();
