import { createHash } from 'node:crypto';
import fs from 'node:fs';
import path from 'node:path';

class Security {
  async readServerCredentials() {
    return new Promise((resolve, reject) => {
      const { CREDENTIALS_PATH = null } = process.env;
      if(CREDENTIALS_PATH) {
        const filePath = path.join(CREDENTIALS_PATH, '.server.credentials.json');
        fs.readFile(filePath, 'utf8', (err, data) => {
          if(err) return reject(err);
          resolve(data);
        });
      } else {
        reject({ message: 'INVALID_CREDENTIALS_PATH' });
      }
    });
  }
  async loadAuthorizedUsers() {
    const credentialsStr = await this.readServerCredentials();
    const credentialsJson = JSON.parse(credentialsStr);
    console.log(credentialsJson);
    if (credentialsJson && credentialsJson.authorized_users) {
      process.env.AUTHORIZED_USERS = JSON.stringify(credentialsJson.authorized_users);
    }
  }

  async isAuthorizedUser(username, password) {
    try {
      if (!process.env.AUTHORIZED_USERS) {
        await this.loadAuthorizedUsers();
      }
      const users = process.env.AUTHORIZED_USERS ? JSON.parse(process.env.AUTHORIZED_USERS) : {};
      console.log('user', users, process.env.AUTHORIZED_USERS);
      if (!users || !users[username]) return false;
      const passwordToVerify = createHash('sha256').update(password).digest('hex');
      const storedPassword = users[username];
      return storedPassword === passwordToVerify;
    } catch(err) {
      console.log(err);
      return false;
    }
  }
}

export default new Security();
